@@ -1,6 +1,6 @@
 /* abstract_crypto.c
  *
- * $Id: abstract_crypto.c,v 1.15 2000/06/04 19:41:19 nisse Exp $ */
+ * $Id: abstract_crypto.c,v 1.18 2001/04/26 04:39:55 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -118,18 +118,32 @@ mac_string(struct mac_algorithm *a,
 
 struct lsh_string *
 crypt_string(struct crypto_instance *c,
-	     struct lsh_string *in,
+	     const struct lsh_string *in,
 	     int free)
 {
-  struct lsh_string *out = (free ? in : lsh_string_alloc(in->length));
+  struct lsh_string *out;
+
+  if (free)
+    {
+      /* Do the encryption in place. The type cast is permissible
+       * because we're conceptually freeing the string and reusing the
+       * storage. */
+      out = (struct lsh_string *) in;
+    }
+  else
+    /* Allocate fresh storage. */
+    out = lsh_string_alloc(in->length);
+  
   CRYPT(c, in->length, in->data, out->data);
   
   return out;
 }
 
+/* FIXME: Missing testcases. This is only used for encrypted private
+ * keys */
 struct lsh_string *
 crypt_string_pad(struct crypto_instance *c,
-		 struct lsh_string *in,
+		 const struct lsh_string *in,
 		 int free)
 {
   struct lsh_string *s;
@@ -148,7 +162,7 @@ crypt_string_pad(struct crypto_instance *c,
 
 struct lsh_string *
 crypt_string_unpad(struct crypto_instance *c,
-		   struct lsh_string *in,
+		   const struct lsh_string *in,
 		   int free)
 {
   struct lsh_string *out;
@@ -160,7 +174,10 @@ crypt_string_unpad(struct crypto_instance *c,
   pad = out->data[out->length - 1];
 
   if ( (pad > 0) && (pad <= c->block_size) )
-    return out;
+    {
+      out->length -= pad;
+      return out;
+    }
   else
     {
       lsh_string_free(out);
