@@ -1,6 +1,6 @@
 /* client.c
  *
- * $Id: client.c,v 1.115 2001/04/10 15:47:02 nisse Exp $ */
+ * $Id: client.c,v 1.120 2001/06/26 16:31:42 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -33,6 +33,7 @@
 #include "pad.h"
 #include "parse.h"
 #include "ssh.h"
+#include "suspend.h"
 #include "tcpforward_commands.h"
 #include "translate_signal.h"
 #include "werror.h"
@@ -59,6 +60,8 @@
 
 #include "client.c.x"
 
+#define DEFAULT_ESCAPE_CHAR '~'
+
 static struct lsh_string *
 format_service_request(int name)
 {
@@ -387,6 +390,8 @@ init_client_options(struct client_options *self,
 {
   self->backend = backend;
   self->tty = make_unix_interact(backend);
+  self->escape = -1;
+  
   self->handler = handler;
 
   self->exit_code = exit_code;
@@ -482,6 +487,8 @@ client_options[] =
   { "pty", 't', NULL, 0, "Request a remote pty (default).", 0 },
   { "no-pty", 't' | ARG_NOT, NULL, 0, "Don't request a remote pty.", 0 },
 #endif /* WITH_PTY_SUPPORT */
+  { "escape-char", 'e', "Character", 0, "Escape char. `none' means disable. "
+    "Default is to use `~' if we have a tty, otherwise none.", 0 },
   { NULL, 0, NULL, 0, NULL, 0 }
 };
 
@@ -691,6 +698,7 @@ fork_output(int out)
     }
 }
 
+
 /* Create a session object. stdout and stderr are shared (although
  * with independent lsh_fd objects). stdin can be used by only one
  * session (until something "session-control"/"job-control" is added).
@@ -701,7 +709,10 @@ make_client_session(struct client_options *options)
   int in;
   int out;
   int err;
-
+  int is_tty = 0;
+  
+  struct escape_info *escape = NULL;
+  
   debug("lsh.c: Setting up stdin\n");
 
   if (options->stdin_file)
@@ -713,10 +724,12 @@ make_client_session(struct client_options *options)
       else 
 	{
 	  in = (options->stdin_fork ? fork_input : dup)(STDIN_FILENO);
+	  is_tty = isatty(STDIN_FILENO);
+	  
 	  options->used_stdin = 1;
 	}
     }
-    
+
   if (in < 0)
     {
       werror("lsh: Can't dup/open stdin (errno = %i): %z!\n",
@@ -724,6 +737,24 @@ make_client_session(struct client_options *options)
       return NULL;
     }
 
+  /* Attach the escape char handler, if appropriate. */
+  if (options->escape > 0)
+    {
+      verbose("Enabling explicit escape character `%pc'\n",
+	      options->escape);
+      escape = make_escape_info(options->escape);
+    }
+  else if ( (options->escape < 0) && is_tty)
+    {
+      verbose("Enabling default escape character `%pc'\n",
+	      DEFAULT_ESCAPE_CHAR);
+      escape = make_escape_info(DEFAULT_ESCAPE_CHAR);
+    }
+
+  /* Bind ^Z to suspend. */
+  if (escape)
+    escape->dispatch[26] = &suspend_callback;
+  
   debug("lsh.c: Setting up stdout\n");
 
   if (options->stdout_file)
@@ -774,10 +805,12 @@ make_client_session(struct client_options *options)
      io_write(make_lsh_fd(options->backend,
 			  err, "client stderr", options->handler),
 	      BLOCK_SIZE, NULL),
+     escape,
      WINDOW_SIZE,
      options->exit_code);
 }
 
+
 /* Parse the argument for -R and -L */
 int
 client_parse_forward_arg(char *arg,
@@ -902,6 +935,8 @@ client_argp_parser(int key, char *arg, struct argp_state *state)
       if (options->start_shell)
 	client_add_action(options, client_shell_session(options));
 
+      /* Install suspend-handler */
+      suspend_install_handler();
       break;
 
     case 'p':
@@ -912,6 +947,16 @@ client_argp_parser(int key, char *arg, struct argp_state *state)
       options->user = arg;
       break;
 
+    case 'e':
+      if (arg[0] && !arg[1])
+	/* A single char argument */
+	options->escape = arg[0];
+      else if (!strcasecmp(arg, "none"))
+	options->escape = 0;
+      else
+	argp_error(state, "Invalid escape char: `%s'. "
+		   "You must use a single character or `none'.", arg);
+      break;
     case 'E':
       client_add_action(options, client_command_session(options, ssh_format("%lz", arg)));
       break;
@@ -1007,6 +1052,7 @@ client_argp_parser(int key, char *arg, struct argp_state *state)
 		goto loop_done;
 	      }
 	loop_done:
+          ;
 	}
       break;
 		
