@@ -2,7 +2,7 @@
  *
  * Simple mark&sweep garbage collector.
  *
- * $Id: gc.h,v 1.6 1999/09/07 20:07:55 nisse Exp $ */
+ * $Id: gc.h,v 1.8 2001/04/17 18:59:34 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -34,4 +34,11 @@ void gc_kill(struct lsh_object *o);
 void gc(struct lsh_object *root);
 void gc_maybe(struct lsh_object *root, int busy);
 
+#if DEBUG_ALLOC
+extern int gc_final_p;
+void gc_final(void);
+#else
+#define gc_final()
+#endif
+
 #endif /* LSH_GC_H_INCLUDED */
