@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: io.h,v 1.75.2.1 2001/04/12 15:53:57 nisse Exp $ */
+ * $Id: io.h,v 1.77 2001/04/12 12:52:48 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -78,6 +78,9 @@ extern struct lsh_class io_backend_class;
        (next object lsh_fd)
        (fd . int)
 
+       ; For debugging purposes
+       (label . "const char *")
+       
        ;; (backend object io_backend)
        ;; (next_closed object lsh_fd)
        
@@ -226,6 +229,9 @@ make_io_backend(void);
 int io_iter(struct io_backend *b);
 void io_run(struct io_backend *b);
 
+void
+io_final(struct io_backend *b);
+
 struct resource *
 io_signal_handler(struct io_backend *b,
 		  volatile sig_atomic_t *flag,
@@ -273,9 +279,10 @@ void io_set_blocking(int fd);
 void io_set_close_on_exec(int fd);
 void io_init_fd(int fd);
 
-struct lsh_fd *make_lsh_fd(struct io_backend *b,
-			   int fd,
-			   struct exception_handler *e);
+struct lsh_fd *
+make_lsh_fd(struct io_backend *b,
+	    int fd, const char *label,
+	    struct exception_handler *e);
 
 struct exception_handler *
 make_exc_finish_read_handler(struct lsh_fd *fd,
@@ -326,8 +333,6 @@ struct lsh_fd *io_write(struct lsh_fd *fd,
 			UINT32 block_size,
 			struct lsh_callback *close_callback);
 
-void kill_fd(struct lsh_fd *fd);
-
 void close_fd(struct lsh_fd *fd);
 
 /* Stop reading from the fd, and close it as soon as the buffer
