@@ -1,6 +1,6 @@
 /* io_commands.c
  *
- * $Id: io_commands.c,v 1.38 2001/03/25 12:16:25 nisse Exp $
+ * $Id: io_commands.c,v 1.40 2001/04/08 19:00:10 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -102,6 +102,7 @@ make_io_write_file_info(const char *name, int flags, int mode, UINT32 block_size
   return self;
 }
 
+/* FIXME: Used only by lsh-writekey. Delete? */
 void do_io_read_fd(struct command *s,
 		   struct lsh_object *a,
 		   struct command_continuation *c,
@@ -110,7 +111,8 @@ void do_io_read_fd(struct command *s,
   CAST(io_read_fd, self, s);
   CAST(io_backend, backend, a);
 
-  COMMAND_RETURN(c, make_lsh_fd(backend, self->fd, e));
+  COMMAND_RETURN(c, make_lsh_fd(backend,
+				self->fd, "io_read_stdin", e));
 }
 
 struct io_read_fd io_read_stdin
