@@ -2,7 +2,7 @@
  *
  * Reads a (private) key on stdin, and saves it a private and a public file.
  *
- * $Id: lsh-writekey.c,v 1.7 2000/11/15 17:01:41 nisse Exp $ */
+ * $Id: lsh-writekey.c,v 1.13 2001/04/26 04:59:07 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -28,8 +28,7 @@
 #include "dsa.h"
 #include "format.h"
 #include "io_commands.h"
-/* For read_password() */
-#include "password.h"
+#include "interact.h"
 #include "rsa.h"
 #include "sexp_commands.h"
 #include "spki_commands.h"
@@ -50,9 +49,10 @@
 #endif
 
 #define BLOCK_SIZE 2000
+#define MAX_SEXP_SIZE 5000
 
 static struct read_sexp_command read_sexp
-= STATIC_READ_SEXP(SEXP_TRANSPORT, 0);
+= STATIC_READ_SEXP(SEXP_TRANSPORT, 0, MAX_SEXP_SIZE);
 
 #define READ_SEXP (&read_sexp.super.super)
 
@@ -93,6 +93,8 @@ const char *argp_program_bug_address = BUG_ADDRESS;
        ; Base filename
        (file string)
 
+       (tty object interact)
+       
        (label string)
        (style . sexp_argp_state)
        (passphrase string)
@@ -111,7 +113,10 @@ make_lsh_writekey_options(void)
 {
   NEW(lsh_writekey_options, self);
   self->file = NULL;
-  
+
+  /* We don't need window change tracking. */
+  self->tty = make_unix_interact(NULL);
+    
   self->label = NULL;
   self->style = -1;
 
@@ -182,14 +187,14 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 	    }
 	  else
 	    {
-	      s = ssh_cformat("%lz/.lsh", home);
-	      if (mkdir(s->data, 0755) < 0)
+	      s = ssh_format("%lz/.lsh", home);
+	      if (mkdir(lsh_get_cstring(s), 0755) < 0)
 		{
 		  if (errno != EEXIST)
 		    argp_failure(state, EXIT_FAILURE, errno, "Creating directory %s failed.", s->data);
 		}
 	      lsh_string_free(s);
-	      self->file = ssh_cformat("%lz/.lsh/identity", home);
+	      self->file = ssh_format("%lz/.lsh/identity", home);
 	    }
 	}
       if (self->crypto)
@@ -221,11 +226,13 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 	      struct lsh_string *pw;
 	      struct lsh_string *again;
 
-	      pw = read_password(500, ssh_format("Enter new passphrase: "), 1);
+	      pw = INTERACT_READ_PASSWORD(self->tty, 500,
+					  ssh_format("Enter new passphrase: "), 1);
 	      if (!pw)
 		argp_failure(state, EXIT_FAILURE, 0, "Aborted.");
 
-	      again = read_password(500, ssh_format("Again: "), 1);
+	      again = INTERACT_READ_PASSWORD(self->tty, 500,
+					     ssh_format("Again: "), 1);
 	      if (!again)
 		argp_failure(state, EXIT_FAILURE, 0, "Aborted.");
 
@@ -233,14 +240,14 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 		self->passphrase = pw;
 	      else
 		lsh_string_free(pw);
-
+		  
 	      lsh_string_free(again);
 	    }
 	}
       break;
       
     case 'o':
-      self->file = format_cstring(arg);
+      self->file = make_string(arg);
       break;
 
     case 'i':
@@ -352,10 +359,10 @@ DEFINE_COMMAND_SIMPLE(lsh_writekey_options2transform, a)
 DEFINE_COMMAND_SIMPLE(lsh_writekey_options2public_file, a)
 {
   CAST(lsh_writekey_options, options, a);
-  struct lsh_string *public = ssh_cformat("%lS.pub", options->file);
+  struct lsh_string *public = ssh_format("%lS.pub", options->file);
 
   return
-    &make_io_write_file_info(public->data,
+    &make_io_write_file_info(lsh_get_cstring(public),
 			     O_CREAT | O_EXCL | O_WRONLY,
 			     0644,
 			     BLOCK_SIZE)->super;
@@ -365,7 +372,7 @@ DEFINE_COMMAND_SIMPLE(lsh_writekey_options2private_file, a)
 {
   CAST(lsh_writekey_options, options, a);
   return
-    &make_io_write_file_info(options->file->data,
+    &make_io_write_file_info(lsh_get_cstring(options->file),
 			     O_CREAT | O_EXCL | O_WRONLY,
 			     0600,
 			     BLOCK_SIZE)->super;
@@ -374,20 +381,21 @@ DEFINE_COMMAND_SIMPLE(lsh_writekey_options2private_file, a)
 /* GABA:
    (expr
      (name make_writekey)
-     (globals
-       (open IO_WRITE_FILE)
-       (stdin IO_READ_STDIN))
      (params
        (options object lsh_writekey_options))
      (expr
        (lambda (backend)
-         (let ((key (read_sexp (stdin backend))))
-           (prog1 (print_public options (open backend (options2public_file options))
+         (let ((key (read_sexp (io_read_stdin backend))))
+           (prog1 (print_public options
+	   			(io_write_file backend
+					       (options2public_file options))
 	                        (verifier2public
 				  (signer2verifier
 				    (sexp2signer (options2algorithms options)
 				                 key))))
-	          (print_private options (open backend (options2private_file options))
+	          (print_private options
+		  		 (io_write_file backend
+		  				(options2private_file options))
 		                 (transform options key)))))))
 */
 
