@@ -1,6 +1,6 @@
 /* lsh_types.h
  *
- * $Id: lsh_types.h,v 1.41 2000/11/20 20:09:46 nisse Exp $ */
+ * $Id: lsh_types.h,v 1.43 2001/06/26 22:14:54 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -85,12 +85,6 @@ char *alloca ();
 # define FUNCTION_NAME "Unknown"
 #endif
 
-#if HAVE_C_OFFSETOF
-# define OFFSETOF offsetof
-#else
-# define OFFSETOF(type, field) ((int) &(((type *) 0)->field))
-#endif
-
 /* Stringizing macros */
 #define STRINGIZE1(x) #x
 #define STRINGIZE(x) STRINGIZE1(x)
@@ -116,10 +110,10 @@ char *alloca ();
 
 /* Reads a 32-bit integer, in network byte order */
 #define READ_UINT32(p)				\
-((((UINT32) (p)[0]) << 24)			\
+(  (((UINT32) (p)[0]) << 24)			\
  | (((UINT32) (p)[1]) << 16)			\
  | (((UINT32) (p)[2]) << 8)			\
- | ((UINT32) (p)[3]))
+ |  ((UINT32) (p)[3]))
 
 #define WRITE_UINT32(p, i)			\
 do {						\
@@ -131,14 +125,14 @@ do {						\
 
 /* Same, for 24-bit quantities */
 #define READ_UINT24(p)				\
-((((UINT32) (p)[0]) << 24)			\
+(  (((UINT32) (p)[0]) << 24)			\
  | (((UINT32) (p)[1]) << 16)			\
- | ((UINT32) (p)[2]))
+ |  ((UINT32) (p)[2]))
 
 /* Same, for 16-bit quantities */
 #define READ_UINT16(p)				\
-((((UINT32) (p)[0]) << 16)			\
- | ((UINT32) (p)[1]))
+(  (((UINT32) (p)[0]) << 16)			\
+ |  ((UINT32) (p)[1]))
 
 #define WRITE_UINT16(p, i)			\
 do {						\
