@@ -1,6 +1,6 @@
 /* lshg.c
  *
- * $Id: lshg.c,v 1.8.2.1 2001/04/17 21:41:32 nisse Exp $
+ * $Id: lshg.c,v 1.10 2001/04/17 19:39:38 nisse Exp $
  *
  * Connect to a gateway. */
 
@@ -279,6 +279,9 @@ main(int argc, char **argv)
 
   io_run(backend);
 
+  /* Close all files and other resources associated with the backend. */
+  io_final(backend);
+
   gc_final();
   
   return exit_code;
