@@ -2,7 +2,7 @@
  *
  * PKCS#5 "PBKDF2" style key derivation.
  *
- * $Id: pkcs5.c,v 1.3 2000/05/06 11:17:38 nisse Exp $ */
+ * $Id: pkcs5.c,v 1.5 2001/04/26 04:41:42 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -29,6 +29,7 @@
 #include "xalloc.h"
 
 #include <assert.h>
+#include <string.h>
 
 /* NOTE: The PKCS#5 v2 spec doesn't recommend or specify any
  * particular value of the iteration count.
@@ -67,8 +68,8 @@
 
 void
 pkcs5_derive_key(struct mac_algorithm *prf,
-		 UINT32 password_length, UINT8 *password,
-		 UINT32 salt_length, UINT8 *salt,
+		 UINT32 password_length, const UINT8 *password,
+		 UINT32 salt_length, const UINT8 *salt,
 		 UINT32 iterations,
 		 UINT32 key_length, UINT8 *key)
 {
