@@ -1,6 +1,6 @@
 /* proxy.c
  *
- * $Id: proxy.c,v 1.8 2000/08/04 00:00:05 nisse Exp $ */
+ * $Id: proxy.c,v 1.11 2001/04/04 21:50:48 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -244,7 +244,7 @@ STATIC_COLLECT_1(&chain_connections_2);
        (client_hooks object object_list)))
 */
 
-COMMAND_SIMPLE(chained_connection)
+DEFINE_COMMAND_SIMPLE(chained_connection, a)
 {
   CAST(ssh_connection, connection, a);
   return &connection->chain->super.super;
@@ -324,7 +324,7 @@ do_proxy_accept_service(struct packet_handler *c,
     {
       struct lsh_string *new_packet;
 
-      connection->dispatch[SSH_MSG_SERVICE_ACCEPT] = connection->fail;
+      connection->dispatch[SSH_MSG_SERVICE_ACCEPT] = &connection_fail_handler;
 #if DATAFELLOWS_WORKAROUNDS
       if ((connection->chain->peer_flags & PEER_SERVICE_ACCEPT_KLUDGE) ==
 	  (connection->peer_flags & PEER_SERVICE_ACCEPT_KLUDGE))
@@ -335,7 +335,6 @@ do_proxy_accept_service(struct packet_handler *c,
 	    new_packet = ssh_format("%c", SSH_MSG_SERVICE_ACCEPT);
 	  else
 	    new_packet = ssh_format("%c%a", SSH_MSG_SERVICE_ACCEPT, closure->name);
-	  lsh_string_free(packet);
 	}
 #else
       new_packet = packet;
@@ -347,10 +346,7 @@ do_proxy_accept_service(struct packet_handler *c,
 		   closure->c, closure->e);
     }
   else
-    {
-      lsh_string_free(packet);
-      PROTOCOL_ERROR(closure->e, "Invalid SSH_MSG_SERVICE_ACCEPT message");
-    }
+    PROTOCOL_ERROR(closure->e, "Invalid SSH_MSG_SERVICE_ACCEPT message");
 }
 
 static struct packet_handler *
@@ -403,7 +399,7 @@ do_proxy_service_request(struct packet_handler *c,
 	    {
 	      /* Don't accept any further service requests */
 	      connection->dispatch[SSH_MSG_SERVICE_REQUEST]
-		= connection->fail;
+		= &connection_fail_handler;
 
 	      connection->chain->dispatch[SSH_MSG_SERVICE_ACCEPT]
 		= make_proxy_accept_service_handler(name, service, self->c, self->e);
@@ -418,11 +414,7 @@ do_proxy_service_request(struct packet_handler *c,
 		      make_protocol_exception(SSH_DISCONNECT_SERVICE_NOT_AVAILABLE, NULL));
     }
   else
-    {
-      lsh_string_free(packet);
-      PROTOCOL_ERROR(connection->e, "Invalid SERVICE_REQUEST message");
-    }
-
+    PROTOCOL_ERROR(connection->e, "Invalid SERVICE_REQUEST message");
 }
 
 static struct packet_handler *
