@@ -2,7 +2,7 @@
  *
  * An implementation of SPKI certificate checking
  *
- * $Id: spki.c,v 1.26 2000/10/17 23:38:31 nisse Exp $ */
+ * $Id: spki.c,v 1.29 2001/05/01 18:35:57 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -40,14 +40,6 @@
 #include <assert.h>
 #include <string.h>
 
-#if 0
-#include <sys/types.h>
-#include <fcntl.h>
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-
 #define GABA_DEFINE
 #include "spki.h.x"
 #undef GABA_DEFINE
@@ -117,9 +109,13 @@ spki_make_verifier(struct alist *algorithms,
   struct sexp_iterator *i;
 
   algorithm_name = spki_get_type(e, &i);
-  
-  algorithm = ALIST_GET(algorithms, algorithm_name);
 
+  {
+    CAST_SUBTYPE(signature_algorithm, a, 
+		 ALIST_GET(algorithms, algorithm_name));
+    algorithm = a;
+  }
+  
   if (!algorithm)
     {
       werror("spki_make_verifier: Unsupported algorithm %a.\n", algorithm_name);
@@ -156,7 +152,11 @@ spki_make_signer(struct alist *algorithms,
   if (!algorithm_name)
     return NULL;
   
-  algorithm = ALIST_GET(algorithms, algorithm_name);
+  {
+    CAST_SUBTYPE(signature_algorithm, a, 
+		 ALIST_GET(algorithms, algorithm_name));
+    algorithm = a;
+  }
 
   if (!algorithm)
     {
@@ -248,7 +248,7 @@ make_spki_subject(struct sexp *key,
 static int
 subject_match_hash(struct spki_subject *self,
 		   int method,
-		   struct lsh_string *h1)
+		   const struct lsh_string *h1)
 {
   struct lsh_string *h2;
 
@@ -455,8 +455,8 @@ do_spki_tag_prefix_match(struct spki_tag *s,
 			 struct sexp *e)
 {
   CAST(spki_tag_prefix, self, s);
-  struct lsh_string *ed;
-  struct lsh_string *pd;
+  const struct lsh_string *ed;
+  const struct lsh_string *pd;
 
   assert(sexp_atomp(self->prefix));
   
@@ -731,7 +731,8 @@ spki_add_acl(struct spki_context *ctx,
 
 static struct spki_subject *
 spki_subject_by_hash(struct spki_state *self,
-		     int algorithm, struct lsh_string *hash)
+		     int algorithm,
+		     const struct lsh_string *hash)
 {
   FOR_OBJECT_QUEUE(&self->keys, n)
     {
@@ -758,7 +759,7 @@ do_spki_lookup(struct spki_context *s,
       {
 	/* Syntax: (hash <hash-alg-name> <hash-value> <uris>) */
 	struct spki_subject *subject;
-	struct lsh_string *hash;
+	const struct lsh_string *hash;
 
 	int method = sexp2atom(SEXP_GET(i));
 	if (!method)
