@@ -4,12 +4,16 @@ if [ -z "$srcdir" ] ; then
   srcdir=`pwd`
 fi
 
-if [ -z "$SERVERFLAGS" ] ; then
-    SERVERFLAGS='-q --enable-core'
+if [ -z "$LSHD_FLAGS" ] ; then
+    LSHD_FLAGS='-q --enable-core'
 fi
 
-if [ -z "$CLIENTFLAGS" ] ; then
-    CLIENTFLAGS=-q
+if [ -z "$LSH_FLAGS" ] ; then
+    LSH_FLAGS=-q
+fi
+
+if [ -z "$LSHG_FLAGS" ] ; then
+    LSHG_FLAGS=-q
 fi
 
 if [ -z "$HOSTKEY" ] ; then
@@ -20,6 +24,8 @@ if [ -z "$PIDFILE" ] ; then
     PIDFILE=`pwd`/lshd.$$.pid
 fi
 
+INTERFACE=127.0.0.1
+
 # if [ -z "$USERKEY" ] ; then
 #     USERKEY=$srcdir/key-1.private
 # fi
@@ -59,7 +65,7 @@ spawn_lshd () {
     # Note that --daemon not only forks into the background, it also changes
     # the cwd, uses syslog, etc.
     
-    ../lshd -h $HOSTKEY --interface=localhost \
+    ../lshd -h $HOSTKEY --interface=$INTERFACE \
 	-p $PORT $LSHD_FLAGS --pid-file $PIDFILE --daemon "$@"
 
     # lshd may catch the ordinary TERM signal, leading to timing
@@ -82,28 +88,32 @@ spawn_lshd () {
 }
 
 run_lsh () {
-    cmd=$1
+    cmd="$1"
     shift
-    echo $cmd | ../lsh $CLIENTFLAGS -nt --sloppy-host-authentication \
+    echo "$cmd" | ../lsh $LSH_FLAGS -nt --sloppy-host-authentication \
 	--capture-to /dev/null -z -p $PORT "$@" localhost
 
 }
 
 exec_lsh () {
-    ../lsh $CLIENTFLAGS -nt --sloppy-host-authentication \
+    ../lsh $LSH_FLAGS -nt --sloppy-host-authentication \
 	--capture-to /dev/null -z -p $PORT localhost "$@"
 }
 
 spawn_lsh () {
     # echo spawn_lsh "$@"
-    ../lsh $CLIENTFLAGS -nt --sloppy-host-authentication \
+    ../lsh $LSH_FLAGS -nt --sloppy-host-authentication \
 	--capture-to /dev/null -z -p $PORT "$@" -N localhost &
     at_exit "kill $!"
 }
 
+exec_lshg () {
+    ../lshg $LSHG_FLAGS -nt -p $PORT localhost "$@"
+}
+
 spawn_lshg () {
     # echo spawn_lshg "$@"
-    ../lshg $CLIENTFLAGS -p $PORT "$@" -N localhost &
+    ../lshg $LSHG_FLAGS -p $PORT "$@" -N localhost &
     at_exit "kill $!"
 }
 
