@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: xalloc.h,v 1.25 2001/05/02 05:45:39 nisse Exp $ */
+ * $Id: xalloc.h,v 1.26 2001/06/24 21:08:38 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -94,8 +94,8 @@ extern unsigned number_of_strings;
 
 #else   /* !DEBUG_ALLOC */
 
-#define CHECK_TYPE(c, o) (struct lsh_object *)(o)
-#define CHECK_SUBTYPE(c, o) (struct lsh_object *)(o)
+#define CHECK_TYPE(c, o) ((struct lsh_object *)(o))
+#define CHECK_SUBTYPE(c, o) ((struct lsh_object *)(o))
      
 #define CAST(class, var, o) \
    struct class *(var) = (struct class *) (o)
